@@ -4,7 +4,7 @@
 
 from uproot_methods.classes.TVector2 import TVector2, TVector2Array
 from uproot_methods.classes.TVector3 import TVector3, TVector3Array
-from uproot_methods.classes.TLorentzVector import TLorentzVector, TLorentzVectorArray
+from uproot_methods.classes.TLorentzVector import TLorentzVector, TLorentzVectorArray, PtEtaPhiMassLorentzVector
 
 # convenient access to the version number
 from uproot_methods.version import __version__
